<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * Registers a new admin page, providing content and corresponding menu item for the SEO Settings page.
 *
 * @since 1.0.0
 */
class Bizznis_Admin_SEO_Settings extends Bizznis_Admin_Form {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 */
	function __construct() {
		$page_id  = 'bizznis-seo';
		$menu_ops = apply_filters( 'bizznis_seo_settings_menu_ops',
			array(
				'theme_menu' => array(
					'parent_slug' => 'bizznis',
					'page_title'  => __( 'Theme SEO', 'bizznis' ),
					'menu_title'  => __( 'Theme SEO', 'bizznis' ),
					'capability'  => 'edit_theme_options',
				)
			)
		);
		$page_ops = apply_filters( 'bizznis_seo_settings_page_ops',
			array(
				'screen_icon'       => 'options-bizznis',
				'save_button_text'  => __( 'Save Settings', 'bizznis' ),
				'reset_button_text' => __( 'Reset Settings', 'bizznis' ),
				'saved_notice_text' => __( 'Settings saved.', 'bizznis' ),
				'reset_notice_text' => __( 'Settings reset.', 'bizznis' ),
				'error_notice_text' => __( 'Error saving settings.', 'bizznis' ),
			)
		);
		$settings_field = BIZZNIS_SEO_SETTINGS_FIELD;
		$default_settings = apply_filters( 'bizznis_seo_settings_defaults',
			array(
				'semantic_headings'            => 1,
				'publisher_uri'                => '',
				'append_site_title'            => 0,
				'doctitle_sep'                 => '-',
				'doctitle_seplocation'         => 'right',
				'append_description_home'      => 1,
				'home_h1_on'                   => 'title',
				'home_doctitle'                => '',
				'home_description'             => '',
				'home_noindex'                 => 0,
				'home_nofollow'                => 0,
				'home_noarchive'               => 0,
				'home_author'                  => 0,
				'canonical_archives'           => 1,
				'head_adjacent_posts_rel_link' => 0,
				'head_wlwmanifest_link'        => 0,
				'head_shortlink'               => 0,
				'noindex_cat_archive'          => 1,
				'noindex_tag_archive'          => 1,
				'noindex_author_archive'       => 1,
				'noindex_date_archive'         => 1,
				'noindex_search_archive'       => 1,
				'noarchive_cat_archive'        => 0,
				'noarchive_tag_archive'        => 0,
				'noarchive_author_archive'     => 0,
				'noarchive_date_archive'       => 0,
				'noarchive_search_archive'     => 0,
				'noarchive'                    => 0,
				'noodp'                        => 1,
				'noydir'                       => 1,
			)
		);
		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );
		# Sanitize before saving
		add_action( 'bizznis_settings_sanitizer_init', array( $this, 'sanitizer_filters' ) );
	}

	/**
	 * Register each of the settings with a sanitization filter type.
	 *
	 * @since 1.0.0
	 */
	public function sanitizer_filters() {
		bizznis_add_option_filter(
			'one_zero',
			$this->settings_field,
			array(
				'append_description_home',
				'append_site_title',
				'semantic_headings',
				'home_noindex',
				'home_nofollow',
				'home_noarchive',
				'head_index_rel_link',
				'head_parent_post_rel_link',
				'head_start_post_rel_link',
				'head_adjacent_posts_rel_link',
				'head_wlwmanifest_link',
				'head_shortlink',
				'noindex_cat_archive',
				'noindex_tag_archive',
				'noindex_author_archive',
				'noindex_date_archive',
				'noindex_search_archive',
				'noarchive',
				'noarchive_cat_archive',
				'noarchive_tag_archive',
				'noarchive_author_archive',
				'noarchive_date_archive',
				'noarchive_search_archive',
				'noodp',
				'noydir',
				'canonical_archives',
			)
		);
		bizznis_add_option_filter(
			'no_html',
			$this->settings_field,
			array(
				'home_doctitle',
				'home_description',
				'doctitle_sep',
			)
		);
	}
	
	/**
	 * Contextual help content.
	 *
	 * @since 1.0.0
	 */
	public function help() {
		$screen = get_current_screen();
		$seo_settings_help =
			'<h3>' . __( 'SEO Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( 'Bizznis SEO (search engine optimization) is polite, and will disable itself when most popular SEO plugins (e.g., All-in-One SEO, WordPress SEO, etc.) are active.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'If you don\'t see an SEO Settings sub menu, then you probably have another SEO plugin active.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'If you see the menu, then opening that menu item will let you set the SEO settings for your site.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'Each page, post, and term will have its own SEO settings as well. The default settings are recommended for most users. If you wish to adjust your SEO settings, the boxes include internal descriptions.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'Below you\'ll find a few succinct notes on the options for each box:' , 'bizznis' ) . '</p>';
		$doctitle_help =
			'<h3>' . __( 'Document Title Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( '<strong>Append Site Description</strong> will insert the site description from your Theme Settings after the title on your home page.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( '<strong>Append Site Name</strong> will put the site name from the Theme Settings after the title on inner page.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( '<strong>Doctitle Append Location</strong> determines which side of the title to add the previously mentioned items.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'The <strong>Doctitle Separator</strong> is the character that will go between the title and appended text.' , 'bizznis' ) . '</p>';
		$dochead_help =
			'<h3>' . __( 'Document Head Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( 'The Relationship Link Tags are tags added by WordPress that currently have no SEO value but slow your site load down. They\'re disabled by default, but if you have a specific need &#8212; for a plugin or other non typical use &#8212; then you can enable as needed here.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'You can also add support for Windows Live Writer if you use software that supports this and include a shortlink tag if this is required by any third party service.' , 'bizznis' ) . '</p>';
		$homepage_help =
			'<h3>' . __( 'Homepage Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( 'These are the homepage specific SEO settings. Note: these settings will not apply if a static page is set as the front page. If you\'re using a static WordPress page as your hompage, you\'ll need to set the SEO settings on that particular page.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'You can also specify if the Site Title, Description, or your own custom text should be wrapped in an &lt;h1&gt; tag (the primary heading in HTML).' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'To add custom text you\'ll have to either edit a php file, or use a text widget on a widget enabled homepage.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'The home doctitle sets what will appear within the <title></title> tags (unseen in the browser) for the home page.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'The home META description fill in the meta tags for the home page. The META description is the short text blurb that appear in search engine results.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'The Homepage Robots Meta Tags tell search engines how to handle the homepage. Noindex means not to index the page at all, and it will not appear in search results. Nofollow means do not follow any links from this page and noarchive tells them not to make an archive copy of the page.' , 'bizznis' ) . '</p>';
		$robots_help =
			'<h3>' . __( 'Robots Meta Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( 'Noarchive and noindex are explained in the home settings. Here you can select what other parts of the site to apply these options to.' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'At least one archive should be indexed, but indexing multiple archives will typically result in a duplicate content penalization (multiple pages with identical content look manipulative to search engines).' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'For most sites either the home page or blog page (using the blog template) will serve as this index which is why the default is not to index categories, tags, authors, dates, or searches.' , 'bizznis' ) . '</p>';
		$seoarchives_help =
			'<h3>' . __( 'Archives Settings' , 'bizznis' ) . '</h3>' .
			'<p>' .  __( 'Canonical links will point search engines to the front page of paginated content (search engines have to choose the "preferred link" when there is duplicate content on pages).' , 'bizznis' ) . '</p>' .
			'<p>' .  __( 'This tells them "this is paged content and the first page starts here" and helps to avoid spreading keywords across multiple pages.' , 'bizznis' ) . '</p>';
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-seo-settings',
			'title'	=> __( 'SEO Settings' , 'bizznis' ),
			'content'	=> $seo_settings_help,
		) );
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-doctitle',
			'title'	=> __( 'Document Title Settings' , 'bizznis' ),
			'content'	=> $doctitle_help,
		) );
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-dochead',
			'title'	=> __( 'Document Head Settings' , 'bizznis' ),
			'content'	=> $dochead_help,
		) );
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-homepage',
			'title'	=> __( 'Homepage Settings' , 'bizznis' ),
			'content'	=> $homepage_help,
		) );
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-robots',
			'title'	=> __( 'Robots Meta Settings' , 'bizznis' ),
			'content'	=> $robots_help,
		) );
		$screen->add_help_tab( array(
			'id'	=> $this->pagehook . '-seo-archives',
			'title'	=> __( 'SEO Archives' , 'bizznis' ),
			'content'	=> $seoarchives_help,
		) );
		# Add help sidebar
		$screen->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'bizznis' ) . '</strong></p>' .
			'<p><a href="' . sprintf( __( '%s', 'bizznis' ), 'http://bizzthemes.com/support/' ) . '" target="_blank" title="' . __( 'Get Support', 'bizznis' ) . '">' . __( 'Get Support', 'bizznis' ) . '</a></p>'
		);
	}

	/**
	 * Callback for SEO Settings Form.
	 *
	 * @since 1.0.0
	 */
	public function form() {
		?>
		<!-- Google+ -->
		<h3><?php _e( 'Google+', 'bizznis' ); ?></h3>
		<p class="description"><?php _e( 'Your company\'s Google+ Profile URL. Must be a business, not a personal account.', 'bizznis' ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Publisher URL:', 'bizznis' ); ?></th>
					<td>
						<input type="text" name="<?php echo $this->get_field_name( 'publisher_uri' ); ?>" id="<?php echo $this->get_field_id( 'publisher_uri' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'publisher_uri' ) ); ?>" size="80" />
					</td>
				</tr>
			</tbody>
		</table>
		<!-- HTML5 Headings -->
		<h3><?php _e( 'Section Headings', 'bizznis' ); ?></h3>
		<p class="description"><?php printf( __( 'HTML5 allows for multiple %s tags throughout the document source, provided they are the primary title for the section in which they appear.', 'bizznis' ), bizznis_code( 'h1' ) ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'HTML5 Headings', 'bizznis' ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'semantic_headings' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'semantic_headings' ); ?>" id="<?php echo $this->get_field_id( 'semantic_headings' ); ?>" value="1" <?php checked( $this->get_field_value( 'semantic_headings' ) ); ?> />
						<?php _e( 'Use semantic HTML5 page and section headings throughout site?', 'bizznis' ); ?></label>
					</td>
				</tr>
			</tbody>
		</table>
		<!-- Document Title -->
		<h3><?php _e( 'Document Title', 'bizznis' ); ?></h3>
		<p class="description"><?php printf( __( 'The document %s is the single most important element in your document source for <abbr title="Search engine optimization">SEO</abbr>.', 'bizznis' ), bizznis_code( '<title>' ) ); ?></p>
		<p class="description"><?php _e( 'The title can, and should, be different on each page, but these options will help you control what it will look like by default.', 'bizznis' ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Title Additions', 'bizznis' ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'append_site_title' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'append_site_title' ); ?>" id="<?php echo $this->get_field_id( 'append_site_title' ); ?>" value="1" <?php checked( $this->get_field_value( 'append_site_title' ) ); ?> />
						<?php printf( __( 'Add site name to %s on inner pages?', 'bizznis' ), bizznis_code( '<title>' ) ); ?> </label>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Addition Location', 'bizznis' ); ?></th>
					<td>
						<p>
							<input type="radio" name="<?php echo $this->get_field_name( 'doctitle_seplocation' ); ?>" id="<?php echo $this->get_field_id( 'doctitle_seplocation_left' ); ?>" value="left" <?php checked( $this->get_field_value( 'doctitle_seplocation' ), 'left' ); ?> />
							<label for="<?php echo $this->get_field_id( 'doctitle_seplocation_left' ); ?>"><?php _e( 'Left', 'bizznis' ); ?></label>
							<br />
							<input type="radio" name="<?php echo $this->get_field_name( 'doctitle_seplocation' ); ?>" id="<?php echo $this->get_field_id( 'doctitle_seplocation_right' ); ?>" value="right" <?php checked( $this->get_field_value( 'doctitle_seplocation' ), 'right' ); ?> />
							<label for="<?php echo $this->get_field_id( 'doctitle_seplocation_right' ); ?>"><?php _e( 'Right', 'bizznis' ); ?></label>
						</p>
						<p class="description"><?php _e( 'Determines which side the added title text will go on.', 'bizznis' ); ?></p>
					</td>
				</tr>
				<tr>
					<th scope="row" valign="top"><?php _e( 'Separator', 'bizznis' ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'doctitle_sep' ); ?>"><?php _e( 'Document Title Separator:', 'bizznis' ); ?></label>
						<input type="text" name="<?php echo $this->get_field_name( 'doctitle_sep' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'doctitle_sep' ) ); ?>" size="15" /><br />
						<p class="description"><?php _e( 'If the title consists of two parts (original title and optional addition), then the separator will go in between them.', 'bizznis' ); ?></p>
					</td>
				</tr>
			</tbody>
		</table>
		<!-- Document Head -->
		<h3><?php _e( 'Document Head', 'bizznis' ); ?></h3>
		<p class="description"><?php printf( __( 'By default, WordPress places several tags in your document %1$s. ', 'bizznis' ), bizznis_code( '<head>' ) ); ?></p>
		<p class="description"><?php _e( 'Most of these tags are completely unnecessary, and provide no <abbr title="Search engine optimization">SEO</abbr> value whatsoever; they just make your site slower to load.', 'bizznis' ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php printf( __( 'Add to %s', 'bizznis' ), bizznis_code( '<head>' ) ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'head_adjacent_posts_rel_link' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_adjacent_posts_rel_link' ); ?>" id="<?php echo $this->get_field_id( 'head_adjacent_posts_rel_link' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_adjacent_posts_rel_link' ) ); ?> />
						<?php printf( __( 'Adjacent Posts %s link tags', 'bizznis' ), bizznis_code( 'rel' ) ); ?></label>
						<br />
						<label for="<?php echo $this->get_field_id( 'head_wlmanifest_link' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_wlwmanifest_link' ); ?>" id="<?php echo $this->get_field_id( 'head_wlmanifest_link' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_wlwmanifest_link' ) ); ?> />
						<?php printf( __( 'Include Windows Live Writer Support Tag?', 'bizznis' ) ); ?></label>
						<br />
						<label for="<?php echo $this->get_field_id( 'head_shortlink' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'head_shortlink' ); ?>" id="<?php echo $this->get_field_id( 'head_shortlink' ); ?>" value="1" <?php checked( $this->get_field_value( 'head_shortlink' ) ); ?> />
						<?php printf( __( 'Include Shortlink tag?', 'bizznis' ) ); ?></label>
						<p class="description"><?php _e( '<span class="bizznis-admin-note">Note:</span> The shortlink tag might have some use for 3rd party service discoverability, but it has no <abbr title="Search engine optimization">SEO</abbr> value whatsoever.', 'bizznis' ); ?></p>
					</td>
				</tr>
			</tbody>
		</table>
		<!-- Homepage -->
		<h3><?php _e( 'Homepage', 'bizznis' ); ?></h3>
		<p class="description"><?php _e( 'These are the homepage specific SEO settings. ', 'bizznis' ); ?></p>
		<p class="description"><?php _e( 'Note: these settings will not apply if a static page is set as the front page. In that case, you\'ll need to set the SEO settings on that particular page.', 'bizznis' ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top" id="bizznis_seo_h1_wrap">
					<th scope="row" valign="top"><?php printf( __( 'Wrap in %s tags?', 'bizznis' ), bizznis_code( 'h1' ) ); ?></th>
					<td>
						<input type="radio" name="<?php echo $this->get_field_name( 'home_h1_on' ); ?>" id="<?php echo $this->get_field_id( 'home_h1_on_title' ); ?>" value="title" <?php checked( $this->get_field_value( 'home_h1_on' ), 'title' ); ?> />
						<label for="<?php echo $this->get_field_id( 'home_h1_on_title' ); ?>"><?php _e( 'Site Title', 'bizznis' ); ?></label>
						<br />
						<input type="radio" name="<?php echo $this->get_field_name( 'home_h1_on' ); ?>" id="<?php echo $this->get_field_id( 'home_h1_on_description' ); ?>" value="description" <?php checked( $this->get_field_value( 'home_h1_on' ), 'description' ); ?> />
						<label for="<?php echo $this->get_field_id( 'home_h1_on_description' ); ?>"><?php _e( 'Site Description (Tagline)', 'bizznis' ); ?></label>
						<br />
						<input type="radio" name="<?php echo $this->get_field_name( 'home_h1_on' ); ?>" id="<?php echo $this->get_field_id( 'home_h1_on_neither' ); ?>" value="neither" <?php checked( $this->get_field_value( 'home_h1_on' ), 'neither' ); ?> />
						<label for="<?php echo $this->get_field_id( 'home_h1_on_neither' ); ?>"><?php _e( 'Neither. I\'ll manually wrap my own text on the homepage', 'bizznis' ); ?></label>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Document Title', 'bizznis' ); ?></th>
					<td>
						<input type="text" name="<?php echo $this->get_field_name( 'home_doctitle' ); ?>" id="<?php echo $this->get_field_id( 'home_doctitle' ); ?>" value="<?php echo esc_attr( $this->get_field_value( 'home_doctitle' ) ); ?>" size="80" /><br />
						<p class="description"><?php _e( 'If you leave the document title field blank, your site&#8217;s title will be used instead.', 'bizznis' ); ?></p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Meta Description', 'bizznis' ); ?></th>
					<td>
						<p>
							<label for="<?php echo $this->get_field_id( 'append_description_home' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'append_description_home' ); ?>" id="<?php echo $this->get_field_id( 'append_description_home' ); ?>" value="1" <?php checked( $this->get_field_value( 'append_description_home' ) ); ?> />
							<?php printf( __( 'Add site description (tagline) to %s on home page?', 'bizznis' ), bizznis_code( '<title>' ) ); ?></label>
						</p>
						<br />
						<textarea class="widefat" name="<?php echo $this->get_field_name( 'home_description' ); ?>" id="<?php echo $this->get_field_id( 'home_description' ); ?>" rows="3" cols="70"><?php echo esc_textarea( $this->get_field_value( 'home_description' ) ); ?></textarea><br />
						<p class="description"><?php _e( 'The meta description can be used to determine the text used under the title on search engine results pages.', 'bizznis' ); ?></p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Robots Meta Tags', 'bizznis' ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'home_noindex' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'home_noindex' ); ?>" id="<?php echo $this->get_field_id( 'home_noindex' ); ?>" value="1" <?php checked( $this->get_field_value( 'home_noindex' ) ); ?> />
						<?php printf( __( 'Apply %s to the homepage?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
						<br />
						<label for="<?php echo $this->get_field_id( 'home_nofollow' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'home_nofollow' ); ?>" id="<?php echo $this->get_field_id( 'home_nofollow' ); ?>" value="1" <?php checked( $this->get_field_value( 'home_nofollow' ) ); ?> />
						<?php printf( __( 'Apply %s to the homepage?', 'bizznis' ), bizznis_code( 'nofollow' ) ); ?></label>
						<br />
						<label for="<?php echo $this->get_field_id( 'home_noarchive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'home_noarchive' ); ?>" id="<?php echo $this->get_field_id( 'home_noarchive' ); ?>" value="1" <?php checked( $this->get_field_value( 'home_noarchive' ) ); ?> />
						<?php printf( __( 'Apply %s to the homepage?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
					</td>
				</tr>
			</tbody>
		</table>
		<!-- Robots Meta -->
		<h3><?php _e( 'Robots Meta', 'bizznis' ); ?></h3>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php echo bizznis_code( 'NOINDEX' ); ?></th>
					<td>
						<p>
							<label for="<?php echo $this->get_field_id( 'noindex_cat_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noindex_cat_archive' ); ?>" id="<?php echo $this->get_field_id( 'noindex_cat_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noindex_cat_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Category Archives?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noindex_tag_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noindex_tag_archive' ); ?>" id="<?php echo $this->get_field_id( 'noindex_tag_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noindex_tag_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Tag Archives?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noindex_author_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noindex_author_archive' ); ?>" id="<?php echo $this->get_field_id( 'noindex_author_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noindex_author_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Author Archives?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noindex_date_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noindex_date_archive' ); ?>" id="<?php echo $this->get_field_id( 'noindex_date_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noindex_date_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Date Archives?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noindex_search_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noindex_search_archive' ); ?>" id="<?php echo $this->get_field_id( 'noindex_search_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noindex_search_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Search Archives?', 'bizznis' ), bizznis_code( 'noindex' ) ); ?></label>
						</p>
						<p class="description"><?php _e( 'Depending on your situation, you may or may not want the following archive pages to be indexed by search engines. Only you can make that determination.', 'bizznis' ); ?></p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php echo bizznis_code( 'NOARCHIVE' ); ?></th>
					<td>
						<p>
							<label for="<?php echo $this->get_field_id( 'noarchive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive' ) ); ?> />
							<?php printf( __( 'Apply %s to Entire Site?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
						</p>
						<br />
						<p id="bizznis_noarchive_all_wrap">
							<label for="<?php echo $this->get_field_id( 'noarchive_cat_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive_cat_archive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive_cat_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive_cat_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Category Archives?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noarchive_tag_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive_tag_archive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive_tag_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive_tag_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Tag Archives?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noarchive_author_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive_author_archive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive_author_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive_author_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Author Archives?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noarchive_date_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive_date_archive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive_date_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive_date_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Date Archives?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noarchive_search_archive' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noarchive_search_archive' ); ?>" id="<?php echo $this->get_field_id( 'noarchive_search_archive' ); ?>" value="1" <?php checked( $this->get_field_value( 'noarchive_search_archive' ) ); ?> />
							<?php printf( __( 'Apply %s to Search Archives?', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></label>
						</p>
						<p class="description"><?php printf( __( 'Some search engines will cache pages in your site (e.g. Google Cache). The %1$s tag will prevent them from doing so.', 'bizznis' ), bizznis_code( 'noarchive' ) ); ?></p>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top"><?php printf( __( '%s and %s', 'bizznis' ), bizznis_code( 'NOODP' ), bizznis_code( 'NOYDIR' ) ); ?></th>
					<td>
						<p>
							<label for="<?php echo $this->get_field_id( 'noodp' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noodp' ); ?>" id="<?php echo $this->get_field_id( 'noodp' ); ?>" value="1" <?php checked( $this->get_field_value( 'noodp' ) ); ?> />
							<?php printf( __( 'Apply %s to your site?', 'bizznis' ), bizznis_code( 'nooodp' ) ) ?></label>
							<br />
							<label for="<?php echo $this->get_field_id( 'noydir' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'noydir' ); ?>" id="<?php echo $this->get_field_id( 'noydir' ); ?>" value="1" <?php checked( $this->get_field_value( 'noydir' ) ); ?> />
							<?php printf( __( 'Apply %s to your site?', 'bizznis' ), bizznis_code( 'noydir' ) ) ?></label>
						</p>
						<p class="description"><?php _e( 'Occasionally, search engines use resources like the DMOZ and the Yahoo! Directory to find titles and descriptions for your content. Generally, you will not want them to do this.', 'bizznis' ); ?></p>
					</td>
				</tr>
			</tbody>
		</table>
		<!-- Archives -->
		<h3><?php _e( 'Archives', 'bizznis' ); ?></h3>
		<p class="description"><?php _e( 'Point search engines to the first page of an archive, if viewing a paginated page. If you do not know what this means, leave it on.', 'bizznis' ); ?></p>
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top"><?php _e( 'Canonical Archives', 'bizznis' ); ?></th>
					<td>
						<label for="<?php echo $this->get_field_id( 'canonical_archives' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'canonical_archives' ); ?>" id="<?php echo $this->get_field_id( 'canonical_archives' ); ?>" value="1" <?php checked( $this->get_field_value( 'canonical_archives' ) ); ?> />
						<?php printf( __( 'Canonical Paginated Archives', 'bizznis' ) ); ?></label>
					</td>
				</tr>
			</tbody>
		</table>
		<?php
		# The 'bizznis_seo_theme_settings_form' action hook is called at the end of this function.
		do_action( 'bizznis_seo_theme_settings_form', $this->pagehook );
	}

}