<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * Class to control breadcrumbs display.
 *
 * @since 1.0.0
 */
class Bizznis_Breadcrumb {

	# Settings array, a merge of provided values and defaults.
	protected $args = array();

	/**
	 * Constructor. Set up cacheable values and settings.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		# Default arguments
		$this->args = array(
			'home'                    => __( 'Home', 'bizznis' ),
			'sep'                     => ' / ',
			'list_sep'                => ', ',
			'prefix'                  => sprintf( '<nav %s>', bizznis_attr( 'breadcrumb' ) ),
			'suffix'                  => '</nav>',
			'heirarchial_attachments' => true,
			'heirarchial_categories'  => true,
			'labels' => array(
				'prefix'    => __( 'You are here: ', 'bizznis' ),
				'author'    => __( 'Archives for ', 'bizznis' ),
				'category'  => __( 'Archives for ', 'bizznis' ),
				'tag'       => __( 'Archives for ', 'bizznis' ),
				'date'      => __( 'Archives for ', 'bizznis' ),
				'search'    => __( 'Search for ', 'bizznis' ),
				'tax'       => __( 'Archives for ', 'bizznis' ),
				'post_type' => __( 'Archives for ', 'bizznis' ),
				'404'       => __( 'Not found ', 'bizznis' )
			)
		);
	}

	/**
	 * Return the final completed breadcrumb in markup wrapper.
	 *
	 * @since 1.0.0
	 */
	public function get_output( $args = array() ) {
		// Merge and filter user and default arguments
		$this->args = apply_filters( 'bizznis_breadcrumb_args', wp_parse_args( $args, $this->args ) );
		return $this->args['prefix'] . $this->args['labels']['prefix'] . $this->build_crumbs() . $this->args['suffix'];
	}

	/**
	 * Echo the final completed breadcrumb in markup wrapper.
	 *
	 * @since 1.0.0
	 */
	public function output( $args = array() ) {
		echo $this->get_output( $args );
	}

	/**
	 * Return the correct crumbs for this query, combined together.
	 *
	 * @since 1.0.0
	 */
	protected function build_crumbs() {
		$crumbs[] = $this->get_home_crumb();
		if ( is_home() ) {
			$crumbs[] = $this->get_blog_crumb();
		}
		elseif ( is_search() ) {
			$crumbs[] = $this->get_search_crumb();
		}
		elseif ( is_404() ) {
			$crumbs[] = $this->get_404_crumb();
		}
		elseif ( is_page() ) {
			$crumbs[] = $this->get_page_crumb();
		}
		elseif ( is_archive() ) {
			$crumbs[] = $this->get_archive_crumb();
		}
		elseif ( is_singular() ) {
			$crumbs[] = $this->get_single_crumb();
		}
		return join( $this->args['sep'], array_filter( array_unique( $crumbs ) ) );
	}

	/**
	 * Return archive breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_archive_crumb() {
		if ( is_category() ) {
			$crumb = $this->get_category_crumb();
		}
		elseif ( is_tag() ) {
			$crumb = $this->get_tag_crumb();
		}
		elseif ( is_tax() ) {
			$crumb = $this->get_tax_crumb();
		}
		elseif ( is_year() ) {
			$crumb = $this->get_year_crumb();
		}
		elseif ( is_month() ) {
			$crumb = $this->get_month_crumb();
		}
		elseif ( is_day() ) {
			$crumb = $this->get_day_crumb();
		}
		elseif ( is_author() ) {
			$crumb = $this->get_author_crumb();
		}
		elseif ( is_post_type_archive() ) {
			$crumb = $this->get_post_type_crumb();
		}
		return apply_filters( 'bizznis_archive_crumb', $crumb, $this->args );
	}

	/**
	 * Get single breadcrumb, including any parent crumbs.
	 *
	 * @since 1.0.0
	 */
	protected function get_single_crumb() {
		if ( is_attachment() ) {
			$crumb = $this->get_attachment_crumb();
		}
		elseif ( is_singular( 'post' ) ) {
			$crumb = $this->get_post_crumb();
		}
		else {
			$crumb = $this->get_cpt_crumb();
		}
		return apply_filters( 'bizznis_single_crumb', $crumb, $this->args );
	}

	/**
	 * Return home breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_home_crumb() {
		$url   = $this->page_shown_on_front() ? get_permalink( get_option( 'page_on_front' ) ) : trailingslashit( home_url() );
		$crumb = ( is_home() && is_front_page() ) ? $this->args['home'] : $this->get_breadcrumb_link( $url, sprintf( __( 'View %s', 'bizznis' ), $this->args['home'] ), $this->args['home'] );
		return apply_filters( 'bizznis_home_crumb', $crumb, $this->args );
	}

	/**
	 * Return blog posts page breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_blog_crumb() {
		$crumb = $this->get_home_crumb();
		if ( $this->page_shown_on_front() ) {
			$crumb = get_the_title( get_option( 'page_for_posts' ) );
		}
		return apply_filters( 'bizznis_blog_crumb', $crumb, $this->args );
	}

	/**
	 * Return search results page breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_search_crumb() {
		$crumb = $this->args['labels']['search'] . '"' . esc_html( apply_filters( 'the_search_query', get_search_query() ) ) . '"';
		return apply_filters( 'bizznis_search_crumb', $crumb, $this->args );
	}

	/**
	 * Return 404 (page not found) breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_404_crumb() {
		$crumb = $this->args['labels']['404'];
		return apply_filters( 'bizznis_404_crumb', $crumb, $this->args );
	}

	/**
	 * Return content page breadcrumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_page_crumb() {
		global $wp_query;
		if ( $this->page_shown_on_front() && is_front_page() ) {
			 # Don't do anything - we're on the front page and we've already dealt with that elsewhere
			$crumb = $this->get_home_crumb(); 
		} else {
			$post = $wp_query->get_queried_object();
			# If this is a top level Page, it's simple to output the breadcrumb
			if ( 0 == $post->post_parent ) {
				$crumb = get_the_title();
			} else {
				if ( isset( $post->ancestors ) ) {
					if ( is_array( $post->ancestors ) ) {
						$ancestors = array_values( $post->ancestors );
					}
					else {
						$ancestors = array( $post->ancestors );
					}
				} else {
					$ancestors = array( $post->post_parent );
				}
				$crumbs = array();
				foreach ( $ancestors as $ancestor ) {
					array_unshift(
						$crumbs,
						$this->get_breadcrumb_link(
							get_permalink( $ancestor ),
							sprintf( __( 'View %s', 'bizznis' ), get_the_title( $ancestor ) ),
							get_the_title( $ancestor )
						)
					);
				}
				# Add the current page title
				$crumbs[] = get_the_title( $post->ID );
				$crumb = join( $this->args['sep'], $crumbs );
			}
		}
		return apply_filters( 'bizznis_page_crumb', $crumb, $this->args );
	}

	/**
	 * Get breadcrumb for single attachment, including any parent crumbs.
	 *
	 * @since 1.0.0
	 */
	protected function get_attachment_crumb() {
		global $post;
		$crumb = '';
		if ( $this->args['heirarchial_attachments'] ) {
			# If showing attachment parent
			$attachment_parent = get_post( $post->post_parent );
			$crumb = $this->get_breadcrumb_link(
				get_permalink( $post->post_parent ),
				sprintf( __( 'View %s', 'bizznis' ), $attachment_parent->post_title ),
				$attachment_parent->post_title,
				$this->args['sep']
			);
		}
		$crumb .= single_post_title( '', false );
		return $crumb;
	}

	/**
	 * Get breadcrumb for single post, including any parent (category) crumbs.
	 *
	 * @since 1.0.0
	 */
	protected function get_post_crumb() {
		global $post;
		$categories = get_the_category( $post->ID );
		if ( 1 == count( $categories ) ) {
			# If in single category, show it, and any parent categories
			$crumb = $this->get_term_parents( $categories[0]->cat_ID, 'category', true ) . $this->args['sep'];
		}
		if ( count( $categories ) > 1 ) {
			if ( ! $this->args['heirarchial_categories'] ) {
				# Don't show parent categories (unless the post happen to be explicitly in them)
				foreach ( $categories as $category ) {
					$crumbs[] = $this->get_breadcrumb_link(
						get_category_link( $category->term_id ),
						sprintf( __( 'View all posts in %s', 'bizznis' ), $category->name ),
						$category->name
					);
				}
				$crumb = join( $this->args['list_sep'], $crumbs ) . $this->args['sep'];
			} else {
				# Show parent categories - see if one is marked as primary and try to use that
				$primary_category_id = get_post_meta( $post->ID, '_category_permalink', true ); # support for sCategory Permalink plugin
				if ( $primary_category_id ) {
					$crumb = $this->get_term_parents( $primary_category_id, 'category', true ) . $this->args['sep'];
				} else {
					$crumb = $this->get_term_parents( $categories[0]->cat_ID, 'category', true ) . $this->args['sep'];
				}
			}
		}
		$crumb .= single_post_title( '', false );
		return $crumb;
	}

	/**
	 * Get breadcrumb for single custom post type entry, including any parent (CPT name) crumbs.
	 *
	 * @since 1.0.0
	 */
	protected function get_cpt_crumb() {
		$post_type = get_query_var( 'post_type' );
		$post_type_object = get_post_type_object( $post_type );
		if ( $cpt_archive_link = get_post_type_archive_link( $post_type ) ) {
			$crumb = $this->get_breadcrumb_link( $cpt_archive_link, sprintf( __( 'View all %s', 'bizznis' ), $post_type_object->labels->name ), $post_type_object->labels->name );
		}
		else {
			$crumb = $post_type_object->labels->name;
		}
		$crumb .= $this->args['sep'] . single_post_title( '', false );
		return $crumb;
	}

	/**
	 * Return the category archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_category_crumb() {
		$crumb = $this->args['labels']['category'] . $this->get_term_parents( get_query_var( 'cat' ), 'category' );
		return apply_filters( 'bizznis_category_crumb', $crumb, $this->args );
	}

	/**
	 * Return the tag archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_tag_crumb() {
		$crumb = $this->args['labels']['tag'] . single_term_title( '', false );
		return apply_filters( 'bizznis_tag_crumb', $crumb, $this->args );
	}

	/**
	 * Return the taxonomy archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_tax_crumb() {
		global $wp_query;
		$term  = $wp_query->get_queried_object();
		$crumb = $this->args['labels']['tax'] . $this->get_term_parents( $term->term_id, $term->taxonomy );
		return apply_filters( 'bizznis_tax_crumb', $crumb, $this->args );

	}

	/**
	 * Return the year archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_year_crumb() {
		$crumb = $this->args['labels']['date'] . get_query_var( 'year' );
		return apply_filters( 'bizznis_year_crumb', $crumb, $this->args );
	}

	/**
	 * Return the month archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_month_crumb() {
		$crumb = $this->get_breadcrumb_link(
			get_year_link( get_query_var( 'year' ) ),
			sprintf( __( 'View archives for %s', 'bizznis' ), get_query_var( 'year' ) ),
			get_query_var( 'year' ),
			$this->args['sep']
		);
		$crumb .= $this->args['labels']['date'] . single_month_title( ' ', false );
		return apply_filters( 'bizznis_month_crumb', $crumb, $this->args );
	}

	/**
	 * Return the day archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_day_crumb() {
		global $wp_locale;
		$crumb  = $this->get_breadcrumb_link(
			get_year_link( get_query_var( 'year' ) ),
			sprintf( __( 'View archives for %s', 'bizznis' ), get_query_var( 'year' ) ),
			get_query_var( 'year' ),
			$this->args['sep']
		);
		$crumb .= $this->get_breadcrumb_link(
			get_month_link( get_query_var( 'year' ), get_query_var( 'monthnum' ) ),
			sprintf( __( 'View archives for %s %s', 'bizznis' ), $wp_locale->get_month( get_query_var( 'monthnum' ) ), get_query_var( 'year' ) ),
			$wp_locale->get_month( get_query_var( 'monthnum' ) ),
			$this->args['sep']
		);
		$crumb .= $this->args['labels']['date'] . get_query_var( 'day' ) . date( 'S', mktime( 0, 0, 0, 1, get_query_var( 'day' ) ) );
		return apply_filters( 'bizznis_day_crumb', $crumb, $this->args );
	}

	/**
	 * Return the author archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_author_crumb() {
		global $wp_query;
		$crumb = $this->args['labels']['author'] . esc_html( $wp_query->queried_object->display_name );
		return apply_filters( 'bizznis_author_crumb', $crumb, $this->args );
	}

	/**
	 * Return the post type archive crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_post_type_crumb() {
		$crumb = $this->args['labels']['post_type'] . esc_html( post_type_archive_title( '', false ) );
		return apply_filters( 'bizznis_post_type_crumb', $crumb, $this->args );
	}

	/**
	 * Return recursive linked crumbs of category, tag or custom taxonomy parents.
	 *
	 * @since 1.0.0
	 */
	protected function get_term_parents( $parent_id, $taxonomy, $link = false, array $visited = array() ) {
		$parent = get_term( (int)$parent_id, $taxonomy );
		if ( is_wp_error( $parent ) ) {
			return array();
		}
		if ( $parent->parent && ( $parent->parent != $parent->term_id ) && ! in_array( $parent->parent, $visited ) ) {
			$visited[] = $parent->parent;
			$chain[]   = $this->get_term_parents( $parent->parent, $taxonomy, true, $visited );
		}
		if ( $link && !is_wp_error( get_term_link( get_term( $parent->term_id, $taxonomy ), $taxonomy ) ) ) {
			$chain[] = $this->get_breadcrumb_link( get_term_link( get_term( $parent->term_id, $taxonomy ), $taxonomy ), sprintf( __( 'View all items in %s', 'bizznis' ), $parent->name ), $parent->name );
		} else {
			$chain[] = $parent->name;
		}
		return join( $this->args['sep'], $chain );
	}

	/**
	 * Return anchor link for a single crumb.
	 *
	 * @since 1.0.0
	 */
	protected function get_breadcrumb_link( $url, $title, $content, $sep = false ) {
		$link = sprintf( '<a href="%s" title="%s">%s</a>', esc_attr( $url ), esc_attr( $title ), esc_html( $content ) );
		if ( $sep ) {
			$link .= $sep;
		}
		return $link;
	}

	/**
	 * Determine if static page is shown on front page.
	 *
	 * @since 1.0.0
	 */
	protected function page_shown_on_front() {
		return 'page' == get_option( 'show_on_front' );
	}

}

/**
* Helper function for the Bizznis Breadcrumb Class.
 *
 * @since 1.0.0
 */
function bizznis_breadcrumb( $args = array() ) {
	global $_bizznis_breadcrumb;
	if ( ! $_bizznis_breadcrumb ) {
		$_bizznis_breadcrumb = new Bizznis_Breadcrumb;
	}
	$_bizznis_breadcrumb->output( $args );
}

/**
 * Display Breadcrumbs above the Loop.
 * Concedes priority to popular breadcrumb plugins.
 *
 * @since 1.0.0
 */
add_action( 'bizznis_loop', 'bizznis_do_breadcrumbs', 4 );
function bizznis_do_breadcrumbs() {
	if (
		( ( 'posts' == get_option( 'show_on_front' ) && is_home() ) && ! bizznis_get_option( 'breadcrumb_home' ) ) ||
		( ( 'page' == get_option( 'show_on_front' ) && is_front_page() ) && ! bizznis_get_option( 'breadcrumb_front_page' ) ) ||
		( ( 'page' == get_option( 'show_on_front' ) && is_home() ) && ! bizznis_get_option( 'breadcrumb_posts_page' ) ) ||
		( is_single() && ! bizznis_get_option( 'breadcrumb_single' ) ) ||
		( is_page() && ! bizznis_get_option( 'breadcrumb_page' ) ) ||
		( ( is_archive() || is_search() ) && ! bizznis_get_option( 'breadcrumb_archive' ) ) ||
		( is_404() && ! bizznis_get_option( 'breadcrumb_404' ) ) ||
		( is_attachment() && ! bizznis_get_option( 'breadcrumb_attachment' ) )
	) {
		return;
	}
	# plugins
	if ( function_exists( 'bcn_display' ) ) {
		echo '<div class="breadcrumb" itemprop="breadcrumb">'. bcn_display() .'</div>';
	}
	elseif ( function_exists( 'yoast_breadcrumb' ) ) {
		yoast_breadcrumb( '<div class="breadcrumb">', '</div>' );
	}
	elseif ( function_exists( 'breadcrumbs' ) ) {
		breadcrumbs();
	}
	elseif ( function_exists( 'crumbs' ) ) {
		crumbs();
	}
	else {
		bizznis_breadcrumb(); # native breadcrumbs
	}
}